@@ -166,10 +166,10 @@ class Sysfs(object):
         self._sd_structures = {} # hctl_str : list of device paths
 
         for d in os.listdir(SYSFS_CLASS_ALL_DEVICE_PATH):
-            # listdir returns /dev/sda and /dev/sda1    
+            # listdir returns /dev/sda and /dev/sda1
             if not d.startswith("sd") or d[-1].isdigit():
                 continue
-            
+
             dev_path = os.path.join(SYSFS_CLASS_ALL_DEVICE_PATH,d)
             hctl = get_hctl_for_sd_device(dev_path)
             self._sd_structures.setdefault(hctl, []).append(d)
@@ -185,7 +185,7 @@ class Sysfs(object):
 
         for name, path in self._get_sysfs_block_devices_pathnames().items():
             dev = SysfsBlockDevice(name, path)
-            try:    
+            try:
                 devno = dev.get_block_devno()
                 if devno not in self.block_devno_to_device:
                     self.block_devno_to_device[devno] = dev
@@ -208,10 +208,10 @@ class Sysfs(object):
                 self.sg_disks.append(sd_disk)
                 self.block_devices.append(sd_disk)
                 self.block_devno_to_device[sd_disk.get_block_devno()] = sd_disk
-        
+
 
     def _get_sysfs_block_devices_pathnames(self):
-        """:returns a dict of name:path"""
+        """ Returns a dict of name:path """
         for base in ["/sys/block", ]:
             if os.path.exists(base):
                 #  /sys/class/block/sda ->
